@@ -40,16 +40,32 @@ class CreateDomain(ShowOne):
             'name': parsed_args.name,
         }
         domain = self.app.session.post('/edge/domains', payload)
-        result = self.app.session.get(
-            '/edge/domains/{}/ns-records'.format(domain["id"])
-        )
-        self.app.console.print(
-            "[bold yellow]{}[/bold yellow]".format(
-                "Make sure to set DigiCloud NS records: \n\t [bold blue]{}[/bold blue]".format(
-                    "\n\t ".join(result["digicloud_ns_records"])
+
+        if domain['is_subdomain']:
+            self.app.console.print(
+                "[bold yellow]{}[/bold yellow]"
+                "In order to define a sub-domain in DIGICLOUD, "
+                "you need to verify your ownership on Root Domain. "
+                "Please add a TXT record on your root Domain DNS Setting".format(
+                    "Create a TXT Record like the following: "
+                    "\n\t [bold blue]_digicdn_check.{}[/bold blue] = "
+                    "[bold blue]{}[/bold blue] \n".format(
+                        str(parsed_args.name).split(".")[0], domain["ns_verification"]
+                    )
+                )
+            )
+        else:
+            result = self.app.session.get(
+                '/edge/domains/{}/ns-records'.format(domain["id"])
+            )
+            self.app.console.print(
+                "[bold yellow]{}[/bold yellow]".format(
+                    "Make sure to set DigiCloud NS records: "
+                    "\n\t [bold blue]{}[/bold blue]".format(
+                        "\n\t ".join(result["digicloud_ns_records"])
+                    )
                 )
             )
-        )
         return domain
 
 
@@ -117,9 +133,8 @@ class DisableDomainDNSSEC(ShowOne):
         return dnssec
 
 
-class GetDomainNSRecordSetting(ShowOne):
-    """Get Domain NS record setting"""
-    schema = schemas.DomainNSRecordsDetails()
+class GetDomainNSRecordSetting(Command):
+    """Get Domain/Sub Domain NS record setting"""
 
     def get_parser(self, prog_name):
         parser = super().get_parser(prog_name)
@@ -130,11 +145,33 @@ class GetDomainNSRecordSetting(ShowOne):
         )
         return parser
 
-    def get_data(self, parsed_args):
-        result = self.app.session.get(
-            '/edge/domains/{}/ns-records'.format(parsed_args.domain)
-        )
-        return result
+    def take_action(self, parsed_args):
+        domain = self.app.session.get('/edge/domains/%s' % parsed_args.domain)
+        if domain['is_subdomain']:
+            self.app.console.print(
+                "[bold yellow]{}[/bold yellow]"
+                "In order to define a sub-domain in DIGICLOUD, "
+                "you need to verify your ownership on Root Domain. "
+                "Please add a TXT record on your root Domain DNS Setting".format(
+                    "Create a TXT Record like the following: "
+                    "\n\t [bold blue]_digicdn_check.{}[/bold blue] = "
+                    "[bold blue]{}[/bold blue] \n".format(
+                        str(domain['name']).split(".")[0], domain["ns_verification"]
+                    )
+                )
+            )
+        else:
+            result = self.app.session.get(
+                '/edge/domains/{}/ns-records'.format(parsed_args.domain)
+            )
+            self.app.console.print(
+                "[bold yellow]{}[/bold yellow]".format(
+                    "Please set these NS records: \n"
+                    "\t [bold blue]{}[/bold blue]".format(
+                        "\n\t ".join(result["digicloud_ns_records"])
+                    )
+                )
+            )
 
 
 class VerifyNSRecord(Command):
@@ -160,21 +197,41 @@ class VerifyNSRecord(Command):
                 )
             )
         else:
-            result = self.app.session.get(
-                '/edge/domains/{}/ns-records'.format(parsed_args.domain)
-            )
-            self.app.console.print(
-                "[bold red]{}[/bold red]".format(
-                    "DigiCloud was not able to verify your NS records."
-                )
-            )
-            self.app.console.print(
-                "[bold yellow]{}[/bold yellow]".format(
-                    "Make sure to set DigiCloud NS records: \n\t [bold blue]{}[/bold blue]".format(
-                        "\n\t ".join(result["digicloud_ns_records"])
+            domain = self.app.session.get('/edge/domains/%s' % parsed_args.domain)
+            if domain['is_subdomain']:
+                self.app.console.print(
+                    "[bold red]{}[/bold red]".format(
+                        "DigiCloud was not able to verify your TXT records."
+                    )
+                )
+                self.app.console.print(
+                    "[bold yellow]{}[/bold yellow]"
+                    "In order to define a sub-domain in DIGICLOUD, "
+                    "you need to verify your ownership on Root Domain. "
+                    "Please add a TXT record on your root Domain DNS Setting".format(
+                        "Create a TXT Record like the following: "
+                        "\n\t [bold blue]_digicdn_check.{}[/bold blue] = "
+                        "[bold blue]{}[/bold blue] \n".format(
+                            str(domain['name']).split(".")[0], domain["ns_verification"]
+                        )
+                    )
+                )
+            else:
+                result = self.app.session.get(
+                    '/edge/domains/{}/ns-records'.format(parsed_args.domain)
+                )
+                self.app.console.print(
+                    "[bold red]{}[/bold red]".format(
+                        "DigiCloud was not able to verify your NS records."
+                    )
+                )
+                self.app.console.print(
+                    "[bold yellow]{}[/bold yellow]".format(
+                        "Make sure to set DigiCloud NS records: \n\t [bold blue]{}[/bold blue]".format(
+                            "\n\t ".join(result["digicloud_ns_records"])
+                        )
                     )
                 )
-            )
 
 
 class DeleteDomain(Command):
@@ -1211,17 +1268,10 @@ class UpdateLocation(ShowOne):
             help='edge location path.',
         )
         parser.add_argument(
-            '--path-type',
-            metavar='<path-type>',
-            help='location path type.',
-            choices=("explicit", "prefix", "extension",),
-            type=str.lower,
-        )
-        parser.add_argument(
-            '--path-extensions',
-            metavar='<path-extensions>',
-            help='List location path extensions.',
-            nargs='+',
+            '--path-case-sensitive',
+            metavar='<path-case-sensitive>',
+            help='path case sensitive enabled.',
+            type=t_or_f_or_n,
         )
         parser.add_argument(
             '--upstream',
@@ -1267,6 +1317,35 @@ class UpdateLocation(ShowOne):
             metavar='<cache-zone>',
             help='location cache zone id.',
         )
+        parser.add_argument(
+            '--secure-link-enable',
+            metavar='<secure-link-enable>',
+            help='secure link enabled.',
+            type=t_or_f_or_n,
+        )
+        parser.add_argument(
+            '--secure-link-secret',
+            metavar='<secure-link-secret>',
+            help='secure link secret.',
+        )
+        parser.add_argument(
+            '--redirect-enable',
+            metavar='<redirect-enable>',
+            help='redirect enabled.',
+            type=t_or_f_or_n,
+        )
+        parser.add_argument(
+            '--redirect-url',
+            metavar='<redirect-url>',
+            help='redirect url.',
+        )
+        parser.add_argument(
+            '--redirect-status-code',
+            metavar='<redirect-status-code>',
+            help='redirect status code.',
+            choices=("permanent", "temporary",),
+            type=str.lower,
+        )
         parser.add_argument(
             '--rate-limit',
             metavar='<rate-limit>',
@@ -1275,34 +1354,43 @@ class UpdateLocation(ShowOne):
         return parser
 
     def get_data(self, parsed_args):
+        redirect_status_code_dict = {
+            "permanent": 301,
+            "temporary": 302,
+        }
         uri = '/edge/domains/{}/locations/{}'.format(parsed_args.domain, parsed_args.location)
         payload = {}
+
         if parsed_args.name:
             payload["name"] = parsed_args.name
         if parsed_args.path:
             payload["path"] = parsed_args.path
-        if parsed_args.path_type:
-            payload["path_type"] = parsed_args.path_type
-        if parsed_args.path_extensions:
-            payload["path_extensions"] = parsed_args.path_extensions
+        if parsed_args.path_case_sensitive is not None:
+            payload["path_case_sensitive"] = parsed_args.path_case_sensitive
         if parsed_args.upstream:
-            payload["upstream"] = parsed_args.upstream
+            payload["upstream_id"] = parsed_args.upstream
         if parsed_args.origin_headers:
-            with open(os.path.expanduser(parsed_args.origin_headers)) as file_:
-                origin_headers_content = file_.read()
-                try:
-                    payload["origin_headers"] = json.loads(origin_headers_content)
-                except json.decoder.JSONDecodeError as e:
-                    raise CLIError(
-                        [dict(msg="origin-headers is not a valid json")])
+            if str(parsed_args.origin_headers).lower() == "null":
+                payload["origin_headers"] = []
+            else:
+                with open(os.path.expanduser(parsed_args.origin_headers)) as file_:
+                    origin_headers_content = file_.read()
+                    try:
+                        payload["origin_headers"] = json.loads(origin_headers_content)
+                    except json.decoder.JSONDecodeError as e:
+                        raise CLIError(
+                            [dict(msg="origin-headers is not a valid json")])
         if parsed_args.response_headers:
-            with open(os.path.expanduser(parsed_args.response_headers)) as file_:
-                response_headers_content = file_.read()
-                try:
-                    payload["response_headers"] = json.loads(response_headers_content)
-                except json.decoder.JSONDecodeError as e:
-                    raise CLIError(
-                        [dict(msg="response-headers is not a valid json")])
+            if str(parsed_args.response_headers).lower() == "null":
+                payload["response_headers"] = []
+            else:
+                with open(os.path.expanduser(parsed_args.response_headers)) as file_:
+                    response_headers_content = file_.read()
+                    try:
+                        payload["response_headers"] = json.loads(response_headers_content)
+                    except json.decoder.JSONDecodeError as e:
+                        raise CLIError(
+                            [dict(msg="response-headers is not a valid json")])
         if parsed_args.cache_enabled is not None:
             payload["cache_enabled"] = parsed_args.cache_enabled
         if parsed_args.cache_ttl:
@@ -1313,6 +1401,28 @@ class UpdateLocation(ShowOne):
             payload["cache_cookie_name"] = parsed_args.cache_cookie_name
         if parsed_args.cache_zone:
             payload["cache_zone"] = parsed_args.cache_zone
+        if parsed_args.secure_link_enable is not None:
+            payload["secure_link_enable"] = parsed_args.secure_link_enable
+        if parsed_args.secure_link_secret:
+            payload["secure_link_secret"] = parsed_args.secure_link_secret
+        if parsed_args.redirect_enable is not None:
+            payload["redirect_enable"] = parsed_args.redirect_enable
+            if parsed_args.redirect_enable is True:
+                if not parsed_args.redirect_url:
+                    raise CLIError(
+                        [dict(
+                            msg="You need to specify redirect_url "
+                                "when redirect_enable switch is True"
+                        )]
+                    )
+                if not parsed_args.redirect_status_code:
+                    payload["redirect_status_code"] = 302
+        if parsed_args.redirect_url:
+            payload["redirect_url"] = parsed_args.redirect_url
+        if parsed_args.redirect_status_code:
+            payload["redirect_status_code"] = redirect_status_code_dict[
+                parsed_args.redirect_status_code
+            ]
         if parsed_args.rate_limit:
             payload["rate_limit_id"] = parsed_args.rate_limit
         location = self.app.session.patch(uri, payload)
@@ -1344,19 +1454,10 @@ class CreateLocation(ShowOne):
             required=True,
         )
         parser.add_argument(
-            '--path-type',
-            metavar='<path-type>',
-            help='location path type.',
-            choices=("explicit", "prefix", "extension",),
-            type=str.lower,
-            required=True,
-        )
-        parser.add_argument(
-            '--path-extensions',
-            metavar='<path-extensions>',
-            help='List of location path extensions.',
-            nargs='+',
-            required=False,
+            '--path-case-sensitive',
+            metavar='<path-case-sensitive>',
+            help='path case sensitive enabled.',
+            type=t_or_f_or_n,
         )
         parser.add_argument(
             '--upstream',
@@ -1403,6 +1504,35 @@ class CreateLocation(ShowOne):
             metavar='<cache-zone>',
             help='location cache zone id.',
         )
+        parser.add_argument(
+            '--secure-link-enable',
+            metavar='<secure-link-enable>',
+            help='secure link enabled.',
+            type=t_or_f_or_n,
+        )
+        parser.add_argument(
+            '--secure-link-secret',
+            metavar='<secure-link-secret>',
+            help='secure link secret.',
+        )
+        parser.add_argument(
+            '--redirect-enable',
+            metavar='<redirect-enable>',
+            help='redirect enabled.',
+            type=t_or_f_or_n,
+        )
+        parser.add_argument(
+            '--redirect-url',
+            metavar='<redirect-url>',
+            help='redirect url.',
+        )
+        parser.add_argument(
+            '--redirect-status-code',
+            metavar='<redirect-status-code>',
+            help='redirect status code.',
+            choices=("permanent", "temporary",),
+            type=str.lower,
+        )
         parser.add_argument(
             '--rate-limit',
             metavar='<rate-limit>',
@@ -1411,15 +1541,20 @@ class CreateLocation(ShowOne):
         return parser
 
     def get_data(self, parsed_args):
+        redirect_status_code_dict = {
+            "permanent": 301,
+            "temporary": 302,
+        }
         url = '/edge/domains/{}/locations'.format(parsed_args.domain)
         payload = {
             "name": parsed_args.name,
             "path": parsed_args.path,
-            "path_type": parsed_args.path_type,
             "upstream_id": parsed_args.upstream,
+            "redirect_enable": False,
+            "redirect_status_code": 302,
         }
-        if parsed_args.path_extensions:
-            payload["path_extensions"] = parsed_args.path_extensions
+        if parsed_args.path_case_sensitive is not None:
+            payload["path_case_sensitive"] = parsed_args.path_case_sensitive
         if parsed_args.origin_headers:
             with open(os.path.expanduser(parsed_args.origin_headers)) as file_:
                 origin_headers_content = file_.read()
@@ -1446,6 +1581,26 @@ class CreateLocation(ShowOne):
             payload["cache_cookie_name"] = parsed_args.cache_cookie_name
         if parsed_args.cache_zone:
             payload["cache_zone"] = parsed_args.cache_zone
+        if parsed_args.secure_link_enable is not None:
+            payload["secure_link_enable"] = parsed_args.secure_link_enable
+        if parsed_args.secure_link_secret:
+            payload["secure_link_secret"] = parsed_args.secure_link_secret
+        if parsed_args.redirect_enable is not None:
+            payload["redirect_enable"] = parsed_args.redirect_enable
+            if parsed_args.redirect_enable is True:
+                if parsed_args.redirect_url:
+                    payload["redirect_url"] = parsed_args.redirect_url
+                else:
+                    raise CLIError(
+                        [dict(
+                            msg="You need to specify redirect_url "
+                                "when redirect_enable switch is True"
+                        )]
+                    )
+            if parsed_args.redirect_status_code:
+                payload["redirect_status_code"] = redirect_status_code_dict[
+                    parsed_args.redirect_status_code
+                ]
         if parsed_args.rate_limit:
             payload["rate_limit_id"] = parsed_args.rate_limit
         location = self.app.session.post(url, payload)
