@@ -233,7 +233,8 @@ class CreateInstance(ShowOne):
                 "--count must be greater than 0",
             ),
             (
-                parsed_args.image.lower().startswith('windows') 
+                parsed_args.image
+                    and parsed_args.image.lower().startswith('windows')
                     and parsed_args.root_volume_size 
                     and parsed_args.root_volume_size is not None
                     and parsed_args.root_volume_size < min_windows_root_vol_size,
