@@ -326,7 +326,7 @@ class CreateFrontend(ShowOne):
         parser.add_argument(
             '--default-backend',
             metavar='<default_backend>',
-            required=True,
+            required=False,
             help='default backend which the frontend will forward requests to.',
         )
         return parser
@@ -351,6 +351,68 @@ class CreateFrontend(ShowOne):
         return frontend
 
 
+class SetFrontendDefaultBackend(ShowOne):
+    """Set a new default backend for the specified frontend."""
+    schema = schemas.FrontendDetail()
+
+    def get_parser(self, prog_name):
+        parser = super().get_parser(prog_name)
+        parser.add_argument(
+            'load_balancer',
+            metavar='<load-balancer>',
+            help='Load Balancer name or ID',
+        )
+        parser.add_argument(
+            '--frontend-id',
+            metavar='<frontend_id>',
+            required=True,
+            help='The frontend identifier to be updated.',
+        )
+        parser.add_argument(
+            '--default-backend',
+            metavar='<default_backend>',
+            required=True,
+            help='default backend which the frontend will forward requests to.',
+        )
+        return parser
+
+    def get_data(self, parsed_args):
+        uri = '/load-balancers/{}/frontends/{}'.format(
+            parsed_args.load_balancer, parsed_args.frontend_id
+        )
+        payload = {"default_backend_id": parsed_args.default_backend}
+        frontend = self.app.session.patch(uri, payload)
+        return frontend
+
+
+class DeleteFrontendDefaultBackend(ShowOne):
+    """Delete default backend for the specified frontend."""
+    schema = schemas.FrontendDetail()
+
+    def get_parser(self, prog_name):
+        parser = super().get_parser(prog_name)
+        parser.add_argument(
+            'load_balancer',
+            metavar='<load-balancer>',
+            help='Load Balancer name or ID',
+        )
+        parser.add_argument(
+            '--frontend-id',
+            metavar='<frontend_id>',
+            required=True,
+            help='The frontend identifier to be updated.',
+        )
+        return parser
+
+    def get_data(self, parsed_args):
+        uri = '/load-balancers/{}/frontends/{}'.format(
+            parsed_args.load_balancer, parsed_args.frontend_id
+        )
+        payload = {"default_backend_id": None}
+        frontend = self.app.session.patch(uri, payload)
+        return frontend
+
+
 class DeleteFrontend(Command):
     """Delete a LoadBalancer frontend."""
     def get_parser(self, prog_name):
