@@ -7,6 +7,21 @@ from .base import Lister, ShowOne, Command
 from ..error_handlers import CLIError
 
 
+def enrich_router_interface_details(session, *routers):
+    subnets = {
+        subnet['id']: subnet['name']
+        for subnet in session.get('/subnets')
+    }
+    networks = {
+        network['id']: network['name']
+        for network in session.get('/networks')
+    }
+
+    for router in routers:
+        router['network_name'] = networks.get(router['network_id'], "N/A")
+        router['subnet_name'] = subnets.get(router['subnet_id'], "N/A")
+
+
 class ListRouter(Lister):
     """List Routers."""
     schema = schemas.RouterList(many=True)
@@ -100,8 +115,9 @@ class ListRouterInterface(Lister):
 
     def get_data(self, parsed_args):
         uri = f'/routers/{parsed_args.router}/interfaces'
-        data = self.app.session.get(uri)
-        return data
+        interfaces = self.app.session.get(uri)
+        enrich_router_interface_details(self.app.session, *interfaces)
+        return interfaces
 
 
 class ShowRouterInterface(ShowOne):
@@ -125,9 +141,9 @@ class ShowRouterInterface(ShowOne):
 
     def get_data(self, parsed_args):
         uri = '/routers/%s/interfaces/%s' % (parsed_args.router, parsed_args.interface_id)
-        data = self.app.session.get(uri)
-
-        return data
+        interface = self.app.session.get(uri)
+        enrich_router_interface_details(self.app.session, interface)
+        return interface
 
 
 class AddRouterInterface(ShowOne):
@@ -152,9 +168,9 @@ class AddRouterInterface(ShowOne):
     def get_data(self, parsed_args):
         uri = '/routers/%s/interfaces' % parsed_args.router
         payload = {'subnet': parsed_args.subnet}
-        data = self.app.session.post(uri, payload)
-
-        return data
+        interface = self.app.session.post(uri, payload)
+        enrich_router_interface_details(self.app.session, interface)
+        return interface
 
 
 class RemoveRouterInterface(Command):
