@@ -27,9 +27,14 @@ class ListVolume(Lister):
     schema = schemas.VolumeList(many=True)
 
     def get_data(self, parsed_args):
-        data = self.app.session.get('/volumes')
-
-        return data
+        volumes = self.app.session.get('/volumes')
+        for volume in volumes:
+            volume_instances = []
+            for attachment in volume.get('attached_to', []):
+                instance_name = attachment['instance_id']
+                volume_instances.append(instance_name)
+            volume["attached_to"] = ', '.join(volume_instances)
+        return volumes
 
 
 class ShowVolume(ShowOne):
