@@ -3,6 +3,7 @@
 """
 import re
 import sys
+import uuid
 
 import requests
 
@@ -47,3 +48,13 @@ def compare_versions(left, right):
 
 def convert_camel_to_snake(name):
     return re.sub(r'(?<!^)(?=[A-Z])', '_', name).lower()
+
+
+def t_or_f_or_n(arg):
+    upper_arg = str(arg).upper()
+    if 'TRUE'.startswith(upper_arg):
+        return True
+    elif 'FALSE'.startswith(upper_arg):
+        return False
+    else:
+        return None
